@@ -38,6 +38,9 @@ file_header() {
 test_include() {
 for file in $path/* ;
 do
+   if [[ $file == *"build"* ]]; then
+     continue;
+   fi
    #echo $file;
    if test -d $file ; then
           echo "Check include into directory : $file";
@@ -66,6 +69,7 @@ do
        new=`echo "$new" |perl -pi -e 's!KMime/!!g'`;
        new=`echo "$new" |perl -pi -e 's!KParts/!!g'`;
        new=`echo "$new" |perl -pi -e 's!KNS3/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KNSCore/!!g'`;
        new=`echo "$new" |perl -pi -e 's!KPIMIdentities/!!g'`;
        new=`echo "$new" |perl -pi -e 's!KCalCore/!!g'`;
        new=`echo "$new" |perl -pi -e 's!KPIMUtils/!!g'`;
@@ -97,8 +101,23 @@ do
        new=`echo "$new" |perl -pi -e 's!Qt3DCore/!!g'`;
        new=`echo "$new" |perl -pi -e 's!Qt3DAnimation/!!g'`;
        new=`echo "$new" |perl -pi -e 's!Qt3DRender/!!g'`;
-
-       
+       new=`echo "$new" |perl -pi -e 's!KSieveUi/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KTNEF/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KCodecs/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KSMTP/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KGAPI/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KItinerary/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KRunner/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KIMAP/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KLDAP/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KCoreAddons/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KdepimDBusInterfaces/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KScreen/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KQuickAddons/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KIPI/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KIOWidgets/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KActivities/Stats/!!g'`;
+       new=`echo "$new" |perl -pi -e 's!KI18n/!!g'`;
        newname=`echo "$new" |perl -pi -e 's!.h!!'`;
 
        #echo "before go : $new";
@@ -132,7 +151,13 @@ do
                                 remove_include;
                            fi
                         ;;
-
+			QGuiApplication)
+                           number=`grep qGuiApp  $file|wc -l`;
+                           echo "qApp $number";
+                           if test $number = 0 ; then
+                                remove_include;
+                           fi
+                        ;;
                         QDesktopWidget)
                            number=`grep "Application::desktop"  $file|wc -l`;
                            if test $number = 0 ; then
@@ -349,7 +374,7 @@ do
                            #fi
                         ;;
                         QLoggingCategory)
-                           number=`grep "Q_DECLARE_LOGGING_CATEGORY" $file|wc -l`;
+                           number=`egrep "Q_DECLARE_LOGGING_CATEGORY|Q_LOGGING_CATEGORY" $file|wc -l`;
                            if test $number = 0 ; then
                               number=`egrep "qDebug|qWarning|qCritical"  $file|wc -l`;
                               if test $number = 0 ; then
@@ -363,6 +388,12 @@ do
                               remove_include;
                            fi
                         ;;
+			QMimeData)
+                           number=`grep "mimeData()" $file|wc -l`;
+                           if test $number = 0 ; then
+                              remove_include;
+                           fi
+                        ;;
                         KToolBar)
                            number=`grep "toolBar()" $file|wc -l`;
                            if test $number = 0 ; then
@@ -389,7 +420,6 @@ do
                               remove_include;
                            fi
                         ;;
-
                         QtTest)
                            number=`egrep "QCOMPARE|QVERIFY|QTEST_GUILESS_MAIN|QTEST" $file|wc -l`;
                            if test $number = 0 ; then
